@@ -20,36 +20,38 @@ def countIssue(dt_upt, df_agg_issue):
     today = datetime.today()
     one_day = timedelta(days=1)
     
-    dict_issue_weekly = {}
     dates = dt_upt.date()
     week = 0
-    list_issue= []
-    
     while dates != today.date():
-        temp_list=[]
         week+=1
+        dict_issue_weekly = {}
         for i in range(len(df_agg_issue)):
             issue = 0
             for j in range(7):
                 if df_agg_issue['date'][i].date() == dates:
                     issue+=df_agg_issue['Issue'][i]
-
+                    
                 if dates == today.date():
-                    dict_issue_weekly[df_agg_issue['User Name'][i]] = issue
+                    if df_agg_issue['User Name'][i] not in dict_issue_weekly:
+                        dict_issue_weekly[df_agg_issue['User Name'][i]] = issue
+                    else:
+                        dict_issue_weekly[df_agg_issue['User Name'][i]] = dict_issue_weekly[df_agg_issue['User Name'][i]] + issue
+                        
                     df_issue = pd.DataFrame(list(dict_issue_weekly.items()), columns=['User Name','Issue Total'])
-                    df_issue = df_issue.replace(np.NaN, 0)
-                    save = df_issue.to_csv(r'E:/Materi Kuliah/Semester 8/TA II/!!SIDANG/Revisi/v.03/Hasil/Issue/Base/Issue_week{counter}.csv'.format(counter = week), index = None, header= True)
+                    save = df_issue.to_csv(r'E:/TA/Hasil/Issue/Base/issue_week{counter}.csv'.format(counter = week), index = None, header= True)
                     break; break
                     
                 dates = dates + one_day
-                    
-            dict_issue_weekly[df_agg_issue['User Name'][i]] = issue
-            
+                
+            if df_agg_issue['User Name'][i] not in dict_issue_weekly:       
+                dict_issue_weekly[df_agg_issue['User Name'][i]] = issue
+            else:
+                dict_issue_weekly[df_agg_issue['User Name'][i]] = dict_issue_weekly[df_agg_issue['User Name'][i]] + issue
+                
             dates = dates - timedelta(days=7)
             
         df_issue = pd.DataFrame(list(dict_issue_weekly.items()), columns=['User Name','Issue Total'])
-        df_issue = df_issue.replace(np.NaN, 0)
-        save = df_issue.to_csv(r'E:/Materi Kuliah/Semester 8/TA II/!!SIDANG/Revisi/v.03/Hasil/Issue/Base/Issue_week{counter}.csv'.format(counter = week), index = None, header= True)
+        save = df_issue.to_csv(r'E:/TA/Hasil/Issue/Base/issue_week{counter}.csv'.format(counter = week), index = None, header= True)
         dates = dates + timedelta(days=7)
         
     return week
@@ -58,34 +60,38 @@ def countPR(dt_upt, df_agg_pull):
     today = datetime.today()
     one_day = timedelta(days=1)
     
-    dict_pull_weekly = {}
     dates = dt_upt.date()
     week = 0
     while dates != today.date():
         week+=1
+        dict_pull_weekly = {}
         for i in range(len(df_agg_pull)):
             pull = 0
             for j in range(7):
                 if df_agg_pull['date'][i].date() == dates:
                     pull+=df_agg_pull['Pull'][i]
-                    
                 if dates == today.date():
-                    dict_pull_weekly[df_agg_pull['User Name'][i]] = pull
-                    df_pull = pd.DataFrame(list(dict_pull_weekly.items()), columns=['User Name','PR Total'])
-                    df_pull = df_pull.replace(np.NaN, 0)
-                    save = df_pull.to_csv(r'E:/Materi Kuliah/Semester 8/TA II/!!SIDANG/Revisi/v.03/Hasil/Pull/Base/PR_week{counter}.csv'.format(counter = week), index = None, header= True)
-                    break; break
+                    if df_agg_pull['User Name'][i] not in dict_pull_weekly: 
+                        dict_pull_weekly[df_agg_pull['User Name'][i]] = pull
+                    else:
+                        dict_pull_weekly[df_agg_pull['User Name'][i]] = dict_pull_weekly[df_agg_pull['User Name'][i]] + pull
                     
+                    df_pull = pd.DataFrame(list(dict_pull_weekly.items()), columns=['User Name','PR Total'])
+                    save = df_pull.to_csv(r'E:/TA/Hasil/Pull/Base/PR_week{counter}.csv'.format(counter = week), index = None, header= True)
+                    break; break
+
                 dates = dates + one_day
-                
-            dict_pull_weekly[df_agg_pull['User Name'][i]] = pull
+            
+            if df_agg_pull['User Name'][i] not in dict_pull_weekly: 
+                dict_pull_weekly[df_agg_pull['User Name'][i]] = pull
+            else:
+                dict_pull_weekly[df_agg_pull['User Name'][i]] = dict_pull_weekly[df_agg_pull['User Name'][i]] + pull
+                    
             dates = dates - timedelta(days=7)
 
-        dates = dates + timedelta(days=7)
-        
         df_pull = pd.DataFrame(list(dict_pull_weekly.items()), columns=['User Name','PR Total'])
-        df_pull = df_pull.replace(np.NaN, 0)
-        save = df_pull.to_csv(r'E:/Materi Kuliah/Semester 8/TA II/!!SIDANG/Revisi/v.03/Hasil/Pull/Base/PR_week{counter}.csv'.format(counter = week), index = None, header= True)
+        save = df_pull.to_csv(r'E:/TA/Hasil/Pull/Base/PR_week{counter}.csv'.format(counter = week), index = None, header= True)
+        dates = dates + timedelta(days=7)
         
     return week
 
@@ -99,9 +105,7 @@ def countCommit(api_contributor):
             commit = api_contributor[i]['weeks'][j]['c']
             dict_commit_weekly[api_contributor[i]['author']['login']] = commit
             df_commit = pd.DataFrame(list(dict_commit_weekly.items()), columns=['User Name','Commit Total'])
-            df_commit = df_commit.replace(np.NaN, 0)
-            save = df_commit.to_csv(r'E:/Materi Kuliah/Semester 8/TA II/!!SIDANG/Revisi/v.03/Hasil/Commit/Base/commit_week{counter}.csv'.format(counter = weeks), index = None, header= True)
-
+            save = df_commit.to_csv(r'E:/TA/Hasil/Commit/Base/commit_week{counter}.csv'.format(counter = weeks), index = None, header= True)
 
 def countLOC(api_contributor):
     
@@ -115,5 +119,4 @@ def countLOC(api_contributor):
             loc += api_contributor[i]['weeks'][j]['d']
             dict_loc_weekly[api_contributor[i]['author']['login']] = loc
             df_loc = pd.DataFrame(list(dict_loc_weekly.items()), columns=['User Name','LOC Total'])
-            df_loc = df_loc.replace(np.NaN, 0)
-            save = df_loc.to_csv(r'E:/Materi Kuliah/Semester 8/TA II/!!SIDANG/Revisi/v.03/Hasil/LOC/Base/LOC_week{counter}.csv'.format(counter = weeks), index = None, header= True)
+            save = df_loc.to_csv(r'E:/TA/Hasil/LOC/Base/LOC_week{counter}.csv'.format(counter = weeks), index = None, header= True)
\ No newline at end of file
